AIS.py
======

.. image:: https://travis-ci.org/camptocamp/AIS.py.svg?branch=master
    :target: https://travis-ci.org/camptocamp/AIS.py

AIS.py: a Python interface for the Swisscom All-in Signing Service (aka AIS).

This is **work in progress**! Nothing useful for now.

AIS is a managed service to provide legally valid electronic signatures.

License
-------

Copyright (C) 2016 Camptocamp SA

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.
